import qrcode
import os
import subprocess
import sys
import importlib.util
import tkinter as tk
from tkinter import filedialog, simpledialog, messagebox

# Funktion, um zu prüfen, ob ein Modul installiert ist
def is_module_installed(module_name):
    spec = importlib.util.find_spec(module_name)
    return spec is not None

# Funktion, um tkinter zu installieren, falls es fehlt
def install_tkinter():
    subprocess.check_call([sys.executable, "-m", "pip", "install", "tkinter"])

# Funktion zum Erstellen des QR-Codes
def create_qr_code(url, save_path):
    qr = qrcode.QRCode(
        version=1,
        error_correction=qrcode.constants.ERROR_CORRECT_L,
        box_size=10,
        border=4,
    )
    qr.add_data(url)
    qr.make(fit=True)
    
    img = qr.make_image(fill='black', back_color='white')
    img.save(save_path)
    print(f"QR-Code wurde erfolgreich unter {save_path} gespeichert.")

# Funktion zur Eingabe der URL
def get_url():
    root = tk.Tk()
    root.withdraw()  # Verstecke das Hauptfenster
    url = simpledialog.askstring("URL-Eingabe", "Bitte die URL eingeben, für die ein QR-Code erstellt werden soll:")
    return url

# Funktion zur Auswahl des Speicherorts und Eingabe des Dateinamens
def get_save_path():
    root = tk.Tk()
    root.withdraw()  # Verstecke das Hauptfenster
    
    # Dateiname und Verzeichnis in einem Dialog auswählen
    file_path = filedialog.asksaveasfilename(
        title="Speicherort und Dateiname auswählen für den fertigen QR-Code",
        defaultextension=".png",
        filetypes=[("PNG files", "*.png")],
        initialfile="qr_code.png"
    )
    return file_path

if __name__ == "__main__":
    # Prüfen, ob tkinter installiert ist
    if not is_module_installed("tkinter"):
        print("tkinter ist nicht installiert. Installation wird durchgeführt...")
        install_tkinter()
        print("tkinter wurde erfolgreich installiert.")

    import tkinter as tk
    from tkinter import filedialog, simpledialog
    
    # Schritt 1: URL-Eingabe
    url = get_url()
    
    if not url:
        print("Keine URL eingegeben. Das Programm wird beendet.")
    else:
        # Schritt 2: Speicherort und Dateiname auswählen
        save_path = get_save_path()

        if save_path:
            # QR-Code erstellen und speichern
            create_qr_code(url, save_path)
        else:
            print("Kein Speicherort ausgewählt. Das Programm wird beendet.")
